Struct ssh2_config::Host

source ·
pub struct Host {
    pub pattern: Vec<HostClause>,
    pub params: HostParams,
}
Describes the rules to be used for a certain host

Fields

pattern: Vec<HostClause>

List of hosts for which params are valid. String is string pattern, bool is whether condition is negated

params: HostParams

Implementations

source

impl Host

source

pub fn new(pattern: Vec<HostClause>, params: HostParams) -> Self

source

pub fn intersects(&self, host: &str) -> bool

Returns whether host argument intersects the host clauses