SshConfig

Struct SshConfig 

pub struct SshConfig { /* private fields */ }
Describes the ssh configuration. Configuration is described in this document: http://man.openbsd.org/OpenBSD-current/man5/ssh_config.5

Implementations

Source

impl SshConfig

pub fn from_hosts(hosts: Vec<Host>) -> Self

Constructs a new SshConfig from a list of Hosts.

You can later also set the DefaultAlgorithms using SshConfig::default_algorithms.

use ssh2_config::{DefaultAlgorithms, Host, SshConfig};

let config = SshConfig::from_hosts(vec![/* put your hosts here */]).default_algorithms(DefaultAlgorithms::default());
pub fn query<S: AsRef<str>>(&self, pattern: S) -> HostParams

Query params for a certain host. Returns HostParams for the host.

pub fn intersecting_hosts(&self, pattern: &str) -> impl Iterator<Item = &Host>

Get an iterator over the Hosts which intersect with the given host pattern

pub fn default_algorithms(self, algos: DefaultAlgorithms) -> Self

Set default algorithms for ssh.

If you want to use the default algorithms from the system, you can use the Default::default() method.

pub fn parse( self, reader: &mut impl BufRead, rules: ParseRule, ) -> SshParserResult<Self>

Parse SshConfig from stream which implements BufRead and return parsed configuration or parser error

Example
let mut reader = BufReader::new(
   File::open(Path::new("./assets/ssh.config"))
      .expect("Could not open configuration file")
);

let config = SshConfig::default().parse(&mut reader, ParseRule::STRICT).expect("Failed to parse configuration");
pub fn parse_default_file(rules: ParseRule) -> SshParserResult<Self>

Parse ~/.ssh/config`` file and return parsed configuration [SshConfig`] or parser error

pub fn get_hosts(&self) -> &Vec<Host>

Get list of Hosts in the configuration